@@ -1,16 +1,25 @@
+import requests.exceptions
+
+
 class ZeverSolarError(Exception):
     """
     Base of all exceptions thrown by this package
     """
 
 
-class ZeverSolarTimeout(ZeverSolarError):
+class ZeverSolarInvalidData(ZeverSolarError):
+    """
+    Exception thrown when invalid inverter data is returned
+    """
+
+
+class ZeverSolarTimeout(ZeverSolarError, requests.exceptions.Timeout):
     """
     Exception thrown when a timeout occurs
     """
 
 
-class ZeverSolarHTTPError(ZeverSolarError):
+class ZeverSolarHTTPError(ZeverSolarError, requests.exceptions.HTTPError):
     """
     Exception thrown when an HTTP error occurs
     """
